.. currentmodule:: sardana.pool.poolinstrument

:mod:`~sardana.pool.poolinstrument`
======================================

.. automodule:: sardana.pool.poolinstrument

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolInstrument`


PoolInstrument
-------------------

.. inheritance-diagram:: PoolInstrument
    :parts: 1
    
.. autoclass:: PoolInstrument
    :show-inheritance:
    :members:
    :undoc-members:

